//
//  Module      : kmailq.cpp
//  Author      : Oren Sokoler 
//  E-mail      : orenskl@netvision.net.il
//  Description : This is the main module for kmailq. This program
//                implements the main widget for the application and
//                runs the event loop.
//
//  Copyright (C) 1999 Oren Sokoler
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

//-----------------------------------------------------
//                   C include files
//-----------------------------------------------------

#include <unistd.h>
#include <stdio.h>
#include <ctype.h>
#include <stdlib.h>

//-----------------------------------------------------
//                   Qt include files
//-----------------------------------------------------

#include <qapplication.h>
#include <qpushbutton.h>
#include <qfont.h>
#include <qlistview.h>

//-----------------------------------------------------
//                   KDE include files
//-----------------------------------------------------

#include <kapp.h>

//-----------------------------------------------------
//                   kmailq include files
//-----------------------------------------------------

#include <config.h>
#include "mailqueue.h"

//-----------------------------------------------------
//                      Constants
//-----------------------------------------------------

const int WidgetWidth  = 560;
const int WidgetHeight = 310;

//-----------------------------------------------------
//                   Class MainWindget
//-----------------------------------------------------

class MainWidget : public QWidget
{
public:
  MainWidget ( QWidget *Parent=0, const char *Name=0 );
  ~MainWidget( void );
protected:
  virtual void resizeEvent ( QResizeEvent * );
private:
  QPushButton *Quit;         // Application quit button
  MailQueue   *MailQ;        // The mail queue
};

//-----------------------------------------------------
//	      methods of class MainWidget
//-----------------------------------------------------

// Method      : MainWidget
// Description : MainWidget constructor
// Parameters  : QParent - This widget's parent widget
//               Name    - Widget name   
// Returns     : none.
// Notes       : none.
MainWidget::MainWidget( QWidget *Parent, const char *Name ) 
                  : QWidget( Parent, Name )
{
  int   Opt;        // Command line option
  char *Dir=NULL;   // Spool directory
  int   Time=5;    // Update interval


  setMinimumSize( WidgetWidth , WidgetHeight );
  
  // Parse options
  opterr = 0;    
  while ((Opt = getopt (qApp->argc(),qApp->argv(), "hvd:t:")) != -1) {
    switch (Opt) { 
      case 'v':
	printf("(C) Oren Sokoler.\n");
	printf("%s version %s\n",PACKAGE,VERSION);
	exit(0);
      case 'd':
	Dir = optarg;
	break;
      case 't':
	if ((Time = atoi(optarg)) <= 0) {
	  printf("Illegal argument.\n");
	  exit(1);
	}
	break;
      case 'h':
	printf("Usage : \n\n");
	printf("-v       - Version.\n");
	printf("-d <dir> - Set mail queue spool directory to <dir>.\n");
	printf("-t <sec> - Set mail queue update interval to <sec> seconds.\n");
	printf("-h       - Help. (This message).\n");
	exit(0);
      case '?':
	if (isprint (optopt))
	  fprintf (stderr, "Unknown option `-%c'.\n", optopt);
	else
	  fprintf (stderr,
		     "Unknown option character `\\x%x'.\n",
		   optopt);
	exit(1);
      default:
	break;
    }      
  }  
  
  // Setup mail queue
  
  MailQ = new MailQueue(this,Dir,Time);
  MailQ->setGeometry( 10 , 10  , WidgetWidth - (10 * 2) , 250 );
  MailQ->setFont( QFont( "Times", 16, QFont::Bold ) );
  
  // Setup quit button
  
  Quit = new QPushButton( "Quit", this, "quit" );
  Quit->setGeometry( (WidgetWidth-75) / 2, MailQ->x() + MailQ->height() + 10, 75, 30 );
  Quit->setFont( QFont( "Times", 16, QFont::Bold ) );
    
  connect( Quit, SIGNAL(clicked()), qApp, SLOT(quit()) );    
}

// Method      : ~MainWidget
// Description : MainWidget destructor
// Parameters  : none.
// Returns     : none.
// Notes       : none.
MainWidget::~MainWidget( void )
{
  delete MailQ;
  delete Quit;
}

// Method      : resizeEvent
// Description : Resize event for MainWidget
// Parameters  : QResizeEvent - Qt resize event
// Returns     : none.
// Notes       : none.
void MainWidget::resizeEvent( QResizeEvent * )
{
  // Resize the mail queue and the quit button
  MailQ->resize( width() - (10 * 2) , height() - (10 + 30 + 20));
  Quit->setGeometry( (width()-75) / 2, MailQ->x() + MailQ->height() + 10,75,30);
}

//-----------------------------------------------------
//	            Global functions
//-----------------------------------------------------

// Function    : main
// Description : Program entry point
// Parameters  : argv - arguments vector
//               argc - arguments count
// Returns     : Program exit status :
//
//               0 - Everything is O.K
//
// Notes       : none.
int main( int argc, char **argv )
{
    KApplication App( argc, argv );

    // Create main widget

    MainWidget MainW;

    MainW.setGeometry( 100 , 100 , WidgetWidth , WidgetHeight );
    App.setMainWidget( &MainW );
    MainW.show();

    // Run application

    return App.exec();
}
